@@ -9,7 +9,14 @@ cutoff.edgeworth<-function(xin,   dist, kfun, p1, p2, sig.lev )
 
   RK<-  3/5 # for epanechnikov,  1/(2*sqrt(pi)) #for gaussian, 1/2 # for uniform,
   RKuse<-RK^{3/2}
-  ConvK<- kernel.conv(kernel.conv(0, deriv.order = 0, kernel =  kfun)$kx, deriv.order = 0, kernel =  kfun)$kx #1/(2*sqrt(2*pi)) #fConvolution(kernel)
+  ConvK<- switch(kfun,
+                 Gaussian = 0.2765382,
+                 Epanechnikov = 0.409542,
+                 Triangular = 0.3703704,
+                 Rectangular = 0.3703704,
+                 Biweight = 0.3276294,
+                 Epanechnikov2 = 0.409542
+  ) #kernel.conv(kernel.conv(0, deriv.order = 0, kernel =  kfun)$kx, deriv.order = 0, kernel =  kfun)$kx
   ML.Dens<- NDistDens(xin, dist, p1, p2)
   mu.2 <- mean((DensityEst - ML.Dens)^2)
   nu.2 <- mean(DensityEst^2)
@@ -25,7 +32,7 @@ cutoff.edgeworth<-function(xin,   dist, kfun, p1, p2, sig.lev )
   d0.1<- z.a.sq  *  ConvK * mean(DensityEst^3) *mu.2^3 / (3*SigmaSq^(3/2) )
   d0.2 <- RDeltaR /sqrt(2*nu.2 * RK)
   d0<- d0.1-d0.2
-  d2<- z.a.sq *  mean((DensityEst - ML.Dens)^3)^2  * kernel.fun(0,0, kfun)$kx^2 / SigmaSq^(3/2)
+  d2<- z.a.sq *  mean((DensityEst - ML.Dens)^3)^2  *  kfun(0)^2 / SigmaSq^(3/2)
   cut.off<- z.a + d0 * sqrt.h + d2/( n*sqrt.h)
 
   cut.off
